# lrgasp-submissions

Definition and validators for testing LRGASP submissions

## Documentation
- [Challenges](docs/challenges.md)
- [Submission structure](docs/submission.md)
- Submission formats:
  - [Metadata](docs/metadata.md)
  - [Reference genomes and transcripts](docs/reference-genomes.md)
  - [Transcript model format](docs/model-format.md)
  - [Read to model map format](docs/read_model_map_format.md)
  - [Transcript expression matrix format](docs/expression_matrix_format.md)
- [Pilot data sets](docs/pilot-data.md)

## Submissions

- [On Google Drive](https://drive.google.com/drive/u/0/folders/0AML19cSc1WYeUk9PVA). See Documentation above for the Submission formats and Submission structure.

## Contacts

- [lrgasp-support](mailto:lrgasp-support-group@ucsc.edu) Support list for lrgasp participants. Messages will not be shared publicly
- [lrgasp-announce](mailto:lrgasp-announce-group@ucsc.edu) Announcement list for the Long Read Genome Annotation Assessment Project (LRGASP)


